{-# LANGUAGE DuplicateRecordFields #-}
{-# LANGUAGE NamedFieldPuns        #-}

module Schpin.Walker.Pkg where

import           Control.Monad.Reader           ( runReader )
import           Schpin.SCAD                    ( renderSCAD )
import           Schpin.SRDF.Xml                ( writeSRDFXML )
import           Schpin.URDF.Xml                ( writeURDFXML )
import           Schpin.Walker                  ( PackageConfig
                                                , SimpleWalker
                                                , extendWalker
                                                , pkg_dir
                                                , srdf_subdir
                                                , urdf_subdir
                                                , walker_name
                                                )
import           Schpin.Walker.SCAD             ( getSCADFiles
                                                , renderWalkerStl
                                                )
import           Schpin.Walker.SRDF             ( getSRDF )
import           Schpin.Walker.URDF             ( getURDF )



generateWalkerPackage :: SimpleWalker -> PackageConfig -> IO ()
generateWalkerPackage walker pc = do
  let extended_walker = runReader (extendWalker walker) pc
  mapM_ (uncurry renderSCAD) $ getSCADFiles extended_walker
  writeURDFXML
    (getURDF extended_walker)
    (  pkg_dir pc
    ++ "/"
    ++ urdf_subdir pc
    ++ "/"
    ++ walker_name extended_walker
    ++ ".urdf"
    )
  writeSRDFXML
    (getSRDF extended_walker)
    (  pkg_dir pc
    ++ "/"
    ++ srdf_subdir pc
    ++ "/"
    ++ walker_name extended_walker
    ++ ".srdf"
    )
  renderWalkerStl extended_walker
